package com.srs.comprehensive.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.srs.comprehensive.mapper.CphFileMapper;
import com.srs.comprehensive.domain.CphFile;
import com.srs.comprehensive.service.ICphFileService;

/**
 * 综合素质系统文档Service业务层处理
 * 
 * @author srs
 * @date 2023-07-03
 */
@Service
public class CphFileServiceImpl implements ICphFileService 
{
    @Autowired
    private CphFileMapper cphFileMapper;

    /**
     * 查询综合素质系统文档
     * 
     * @param fileName 综合素质系统文档主键
     * @return 综合素质系统文档
     */
    @Override
    public CphFile selectCphFileByFileName(String fileName)
    {
        return cphFileMapper.selectCphFileByFileName(fileName);
    }

    /**
     * 查询综合素质系统文档列表
     * 
     * @param cphFile 综合素质系统文档
     * @return 综合素质系统文档
     */
    @Override
    public List<CphFile> selectCphFileList(CphFile cphFile)
    {
        return cphFileMapper.selectCphFileList(cphFile);
    }

    /**
     * 新增综合素质系统文档
     * 
     * @param cphFile 综合素质系统文档
     * @return 结果
     */
    @Override
    public int insertCphFile(CphFile cphFile)
    {
        return cphFileMapper.insertCphFile(cphFile);
    }

    /**
     * 修改综合素质系统文档
     * 
     * @param cphFile 综合素质系统文档
     * @return 结果
     */
    @Override
    public int updateCphFile(CphFile cphFile)
    {
        return cphFileMapper.updateCphFile(cphFile);
    }

    /**
     * 批量删除综合素质系统文档
     * 
     * @param fileNames 需要删除的综合素质系统文档主键
     * @return 结果
     */
    @Override
    public int deleteCphFileByFileNames(String[] fileNames)
    {
        return cphFileMapper.deleteCphFileByFileNames(fileNames);
    }

    /**
     * 删除综合素质系统文档信息
     * 
     * @param fileName 综合素质系统文档主键
     * @return 结果
     */
    @Override
    public int deleteCphFileByFileName(String fileName)
    {
        return cphFileMapper.deleteCphFileByFileName(fileName);
    }
}
